@@ -24,7 +24,7 @@ def _partial_emoji_converter(argument: str):
     if len(argument) < 5:
         # Sometimes unicode emojis are actually more than 1 symbol
         return discord.PartialEmoji(name=argument)
-    
+
     match = re.match(r'<(a?):([a-zA-Z0-9\_]+):([0-9]+)>$', argument)
 
     if match:
@@ -47,7 +47,7 @@ def _component_factory(data: dict):
         return SelectMenu.from_dict(data)
 
 
-def auto_rows(*buttons, max_in_row: int=5):
+def auto_rows(*buttons, max_in_row: int = 5):
     """
     Distributes buttons across multiple rows
     and returns the list of rows.
@@ -61,14 +61,14 @@ def auto_rows(*buttons, max_in_row: int=5):
             max_in_row=1
         )
         await ctx.send("Buttons", components=rows)
-    
+
     Parameters
     ----------
     buttons : List[:class:`Button`]
         a list of buttons to distribute
     max_in_row : :class:`int`
         limit of buttons in a single row. Must be between 1 and 5.
-    
+
     Returns
     -------
     List[:class:`ActionRow`]
@@ -76,10 +76,10 @@ def auto_rows(*buttons, max_in_row: int=5):
     """
     if not (1 <= max_in_row <= 5):
         raise discord.InvalidArgument("max_in_row parameter should be between 1 and 5.")
-    rows = []
-    for i in range(0, len(buttons), max_in_row):
-        rows.append(ActionRow(*buttons[i:i + max_in_row]))
-    return rows
+    return [
+        ActionRow(*buttons[i: i + max_in_row])
+        for i in range(0, len(buttons), max_in_row)
+    ]
 
 
 class ComponentType:
@@ -98,20 +98,20 @@ class ButtonStyle:
     red     = 4
     link    = 5
     """
-    primary   = 1
-    blurple   = 1
+    primary = 1
+    blurple = 1
 
     secondary = 2
-    grey      = 2
-    gray      = 2
+    grey = 2
+    gray = 2
 
-    success   = 3
-    green     = 3
+    success = 3
+    green = 3
 
-    danger    = 4
-    red       = 4
+    danger = 4
+    red = 4
 
-    link      = 5
+    link = 5
 
 
 class SelectOption:
@@ -134,16 +134,16 @@ class SelectOption:
 
     __slots__ = ("label", "value", "description", "emoji", "default")
 
-    def __init__(self, label: str, value: str, description: str=None, emoji: str=None, default: bool=False):
+    def __init__(self, label: str, value: str, description: str = None, emoji: str = None, default: bool = False):
         if isinstance(emoji, str):
             emoji = _partial_emoji_converter(emoji)
-        
+
         self.label = label
         self.value = value
         self.description = description
         self.emoji = emoji
         self.default = default
-    
+
     def __repr__(self):
         return (
             "<OptionSelect label='{0.label}' value={0.value} "
@@ -163,7 +163,7 @@ class SelectOption:
             emoji=emoji,
             default=data.get("default", False)
         )
-    
+
     def to_dict(self):
         data = {
             "label": self.label,
@@ -204,7 +204,7 @@ class SelectMenu(Component):
         the choices in the select, max 25
     disabled : :class:`bool`
         disable the menu, defaults to false
-    
+
     Attributes
     ----------
     custom_id : :class:`str`
@@ -223,7 +223,8 @@ class SelectMenu(Component):
         the list of chosen options, max 25
     """
 
-    def __init__(self, *, custom_id: str=None, placeholder: str=None, min_values: int=1, max_values: int=1, options: list=None, disabled: bool=False):
+    def __init__(self, *, custom_id: str = None, placeholder: str = None, min_values: int = 1, max_values: int = 1,
+                 options: list = None, disabled: bool = False):
         super().__init__(3)
         self.custom_id = custom_id or "0"
         self.placeholder = placeholder
@@ -232,7 +233,7 @@ class SelectMenu(Component):
         self.options = options or []
         self.disabled = disabled
         self.selected_options = []
-    
+
     def __repr__(self):
         desc = " ".join(f"{kw}={v}" for kw, v in self.to_dict().items())
         return f"<SelectMenu {desc}>"
@@ -243,7 +244,7 @@ class SelectMenu(Component):
             if option.value in values:
                 self.selected_options.append(option)
 
-    def add_option(self, label: str, value: str, description: str=None, emoji: str=None, default: bool=False):
+    def add_option(self, label: str, value: str, description: str = None, emoji: str = None, default: bool = False):
         """
         Adds an option to the list of options of the menu.
         Parameters are the same as in :class:`SelectOption`.
@@ -307,22 +308,21 @@ class Button(Component):
     disabled : :class:`bool`
         Whether the button is disabled or not. Defaults to false.
     """
-    def __init__(self, *, style: ButtonStyle, label: str=None, emoji: discord.PartialEmoji=None,
-                                    custom_id: str=None, url: str=None, disabled: bool=False):
-        global ID_SOURCE # Ugly as hell
+    def __init__(self, *, style: ButtonStyle, label: str = None, emoji: discord.PartialEmoji = None,
+                 custom_id: str = None, url: str = None, disabled: bool = False):
+        global ID_SOURCE  # Ugly as hell
 
         if custom_id is None:
             if url is None:
                 custom_id = str(ID_SOURCE)
                 ID_SOURCE = (ID_SOURCE + 1) % MAX_ID
-                # raise discord.InvalidArgument("url or custom_id must be specified")
             elif style != ButtonStyle.link:
                 raise discord.InvalidArgument("if you specify url, the style must be ButtonStyle.link")
         elif url is not None:
             raise discord.InvalidArgument("you can't specify both url and custom_id")
         elif style == ButtonStyle.link:
             raise discord.InvalidArgument("style 'link' expects url to be specified")
-        
+
         if isinstance(emoji, str):
             emoji = _partial_emoji_converter(emoji)
 
@@ -333,7 +333,7 @@ class Button(Component):
         self.custom_id = custom_id
         self.url = url
         self.disabled = disabled
-    
+
     def __repr__(self):
         desc = " ".join(f"{kw}={v}" for kw, v in self.to_dict().items())
         return f"<Button {desc}>"
@@ -391,17 +391,17 @@ class ActionRow(Component):
             raise discord.InvalidArgument(f"components must be a list of up to {self._limit} elements")
         if not all(isinstance(comp, Component) for comp in components):
             raise discord.InvalidArgument("components must be a list of Component")
-        
+
         super().__init__(1)
         self.components = list(components)
-    
+
     def __repr__(self):
         return "<ActionRow components={0.components!r}>".format(self)
 
     @property
     def buttons(self):
         return self.components
-    
+
     @classmethod
     def from_dict(cls, data: dict):
         buttons = [_component_factory(elem) for elem in data.get("components", [])]
@@ -427,8 +427,6 @@ class ActionRow(Component):
                 if component.type == ComponentType.Button:
                     component.disabled = True
 
-
-
     def enable_buttons(self, *positions: int):
         """
         Sets ``disabled`` to ``False`` for all buttons in this row.
@@ -443,10 +441,8 @@ class ActionRow(Component):
                 if component.type == ComponentType.Button:
                     component.disabled = False
 
-
-
-    def add_button(self, *, style: ButtonStyle, label: str=None, emoji: str=None,
-                        custom_id: str=None, url: str=None, disabled: bool=False):
+    def add_button(self, *, style: ButtonStyle, label: str = None, emoji: str = None,
+                   custom_id: str = None, url: str = None, disabled: bool = False):
         self.components.append(
             Button(
                 style=style,
@@ -457,8 +453,9 @@ class ActionRow(Component):
                 disabled=disabled
             )
         )
-    
-    def add_menu(self, *, custom_id: str, placeholder: str=None, min_values: int=1, max_values: int=1, options: list=None):
+
+    def add_menu(self, *, custom_id: str, placeholder: str = None, min_values: int = 1, max_values: int = 1,
+                 options: list = None):
         self.components.append(
             SelectMenu(
                 custom_id=custom_id,
